OC.L10N.register(
    "files",
    {
    "Unknown error" : "Unbekannter Fehler",
    "Files" : "Dateien",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "Unshare" : "Teilung zurücknehmen",
    "Details" : "Details",
    "New folder" : "Neuer Ordner",
    "Upload" : "Hochladen",
    "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner hat sich <strong>geändert</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
    "You created %1$s" : "Du hast %1$s erstellt",
    "%2$s created %1$s" : "%2$s erstellte %1$s",
    "You changed %1$s" : "Du hast %1$s geändert",
    "%2$s changed %1$s" : "%2$s änderte %1$s",
    "You deleted %1$s" : "Du hast %1$s gelöscht",
    "%2$s deleted %1$s" : "%2$s löschte %1$s",
    "Save" : "Speichern",
    "Settings" : "Einstellungen",
    "Cancel upload" : "Hochladen abbrechen",
    "You changed %1$s" : "Du hast %1$s geändert",
    "You created %1$s" : "Du hast %1$s erstellt",
    "You deleted %1$s" : "Du hast %1$s gelöscht"
},
"nplurals=2; plural=(n != 1);");
